using System;
using System.IO;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Drawing.Imaging;
using System.Runtime.Serialization.Formatters.Binary;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

//using Microsoft.Win32; //re-enable if attempting to manipulate the registry


namespace lovebook
{
	
/// <summary>
/// Bryan Miller
/// started July, 2006
/// 
/// Contacts application: stores contacts info, including photograph and multiple text field
/// values.
/// 
/// Features:
/// * Warns if you are about to overwrite an already saved contact
/// * Smart password-verification
/// * If you save a contact with a password, one is required to re-open it
/// * Enter password each time, before saving, or it saves file unpassworded
/// * At startup, automatically creates a Contacts subdirectory if one isn't found in \bin\
/// * "hyperlink"-like interface for any valid-format email address, invokes your default mail client
/// * handy hyperlink to webpage help page about the application
/// * can drag *.crf file onto program icon or its shortcut to open it
/// 
/// Wish List:
///
/// * able to bundle all contact files into one big archive file (for back to web, CD, etc.)
/// * user can import bundle and extract it into its constituent contact files
/// * ability to search contacts sequentially for a particular string
/// * when first run, program gives option of installing a shortcut on user's desktop
/// * a field to hold user's website URL; clicking on label takes you to the site
/// * shell integration so that clicking on a *.crf file opens it using the application
/// * a diary, a task list, a notepad, an alarm clock, a calculator
/// 
/// Bug History:
/// 
/// * 08/13/06 disovered that when program inserts the default text 
/// * "DEFAULT NAME VALUE: replace me by typing here" into txtName.Text upon user
/// * clicking the New command button, that if user then immediately attempts to
/// * save to file using the Save Info button, we get this error:
/// * "The given path's format is not supported." due to the presence of the colon.
/// * This is okay, since we want the user to have to enter a sensible name in this 
/// * textbox before saving is possible.  However, a better solution is to disable
/// * the Save Info command button until the user changes the default name.  This is
/// * implemented with EnsureNameOtherThanDefault()   [FIXED]
/// 
/// * 08/12/06 discovered error in btnClick_Delete: had been using the following to
/// * determine if I should make call to file deletion method: 
/// * if(fileDialog.Filename != ""){...}
/// * Inserted code to double-check that there really is such a file as is indicated 
/// * by the fileDialog's .Filename property:
/// * if(File.Exists(fileDialog.FileName)){...}  [FIXED]
/// 
/// * 08/12/06 discovered that Save Info button was not being disabled immediately
/// * afer a file is deleted [FIXED]
/// 
/// * 08/12/06 discovered, in btnDelete_Click, DisplayNumContactsInFormCaption();
/// * was being called before contact_loaded was set to false; flip-flopped their
/// * order so that the value of public boolean contact_loaded would be accurate
/// * when its value is evaluated inside DisplayNumContactsInFormCaption() [FIXED]
/// 
/// * 08/12/06 discovered that statement picImage.Image = null; was being called
/// * multiple times, unnecessarily, due to its inclusion inside a for each loop.
/// * Moved this assignment to occur after the loop [FIXED]
/// 
/// </summary>
	

	public class Form1 : System.Windows.Forms.Form
	{
		private System.Windows.Forms.PictureBox picImage;
		private System.Windows.Forms.Label lblName;
		private System.Windows.Forms.Label lblAddress;
		private System.Windows.Forms.Label lblEmail;
		private System.Windows.Forms.Label lblPhone;
		private System.Windows.Forms.OpenFileDialog fileDialog;
		private System.Windows.Forms.TextBox txtName;
		private System.Windows.Forms.TextBox txtAddress;
		private System.Windows.Forms.TextBox txtEmail;
		private System.Windows.Forms.TextBox txtPhone;
		private System.Windows.Forms.Button btnSaveInfo;
		private System.Windows.Forms.Button btnBrowsePhoto;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.Panel pnlPassword;
		private System.Windows.Forms.TextBox txtPassword;
		private System.Windows.Forms.Label lblPassword;
		private System.Windows.Forms.Button btnDelete;
		private System.Windows.Forms.Label lblYahooID;
		private System.Windows.Forms.TextBox txtYahooID;
		private System.Windows.Forms.Label lblBirthday;
		private System.Windows.Forms.TextBox txtBirthday;
		private System.Windows.Forms.TextBox txtEducation;
		private System.Windows.Forms.Label lblEducation;
		private System.Windows.Forms.Label lblOccupation;
		private System.Windows.Forms.TextBox txtOccupation;
		private System.Windows.Forms.Button btnNew;
        private System.Windows.Forms.TextBox txtNotes;
		private System.Windows.Forms.Button btnOpen;
        private TextBox txtConfirmPassword;
        private Label lblConfirmPassword;
        private Label lblMinLength;

        //my variables
		
        private string current_contact = "Miller, William Bryan";
		private string form_caption = "Contacts Book ";
		private string app_directory = "";
		private string contacts_directory = "";
        private LinkLabel linkLabel1;
		private bool contact_loaded = false;

 
        
		public Form1()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			//
			// TODO: Add any constructor code after InitializeComponent call
			//
			DoForm1ConstructorStuff();

		}

		
		// Clean up any resources being used.
		
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.picImage = new System.Windows.Forms.PictureBox();
            this.btnSaveInfo = new System.Windows.Forms.Button();
            this.txtName = new System.Windows.Forms.TextBox();
            this.txtAddress = new System.Windows.Forms.TextBox();
            this.txtEmail = new System.Windows.Forms.TextBox();
            this.txtPhone = new System.Windows.Forms.TextBox();
            this.lblName = new System.Windows.Forms.Label();
            this.lblAddress = new System.Windows.Forms.Label();
            this.lblEmail = new System.Windows.Forms.Label();
            this.lblPhone = new System.Windows.Forms.Label();
            this.fileDialog = new System.Windows.Forms.OpenFileDialog();
            this.btnBrowsePhoto = new System.Windows.Forms.Button();
            this.txtNotes = new System.Windows.Forms.TextBox();
            this.btnOpen = new System.Windows.Forms.Button();
            this.btnNew = new System.Windows.Forms.Button();
            this.pnlPassword = new System.Windows.Forms.Panel();
            this.lblMinLength = new System.Windows.Forms.Label();
            this.txtConfirmPassword = new System.Windows.Forms.TextBox();
            this.lblConfirmPassword = new System.Windows.Forms.Label();
            this.lblPassword = new System.Windows.Forms.Label();
            this.txtPassword = new System.Windows.Forms.TextBox();
            this.btnDelete = new System.Windows.Forms.Button();
            this.lblYahooID = new System.Windows.Forms.Label();
            this.txtYahooID = new System.Windows.Forms.TextBox();
            this.lblBirthday = new System.Windows.Forms.Label();
            this.txtBirthday = new System.Windows.Forms.TextBox();
            this.lblEducation = new System.Windows.Forms.Label();
            this.txtEducation = new System.Windows.Forms.TextBox();
            this.lblOccupation = new System.Windows.Forms.Label();
            this.txtOccupation = new System.Windows.Forms.TextBox();
            this.linkLabel1 = new System.Windows.Forms.LinkLabel();
            ((System.ComponentModel.ISupportInitialize)(this.picImage)).BeginInit();
            this.pnlPassword.SuspendLayout();
            this.SuspendLayout();
            // 
            // picImage
            // 
            this.picImage.BackColor = System.Drawing.SystemColors.ActiveBorder;
            this.picImage.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
            this.picImage.Location = new System.Drawing.Point(16, 16);
            this.picImage.Name = "picImage";
            this.picImage.Size = new System.Drawing.Size(408, 328);
            this.picImage.SizeMode = System.Windows.Forms.PictureBoxSizeMode.CenterImage;
            this.picImage.TabIndex = 0;
            this.picImage.TabStop = false;
            this.picImage.Click += new System.EventHandler(this.picImage_Click);
            // 
            // btnSaveInfo
            // 
            this.btnSaveInfo.BackColor = System.Drawing.SystemColors.ActiveBorder;
            this.btnSaveInfo.Location = new System.Drawing.Point(322, 537);
            this.btnSaveInfo.Name = "btnSaveInfo";
            this.btnSaveInfo.Size = new System.Drawing.Size(64, 23);
            this.btnSaveInfo.TabIndex = 15;
            this.btnSaveInfo.Text = "&Save Info";
            this.btnSaveInfo.UseVisualStyleBackColor = false;
            this.btnSaveInfo.Click += new System.EventHandler(this.btnSaveInfo_Click);
            // 
            // txtName
            // 
            this.txtName.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtName.Location = new System.Drawing.Point(88, 352);
            this.txtName.Name = "txtName";
            this.txtName.Size = new System.Drawing.Size(312, 21);
            this.txtName.TabIndex = 1;
            this.txtName.Text = "name of contact";
            this.txtName.TextChanged += new System.EventHandler(this.txtName_TextChanged);
            // 
            // txtAddress
            // 
            this.txtAddress.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtAddress.Location = new System.Drawing.Point(88, 376);
            this.txtAddress.Name = "txtAddress";
            this.txtAddress.Size = new System.Drawing.Size(312, 21);
            this.txtAddress.TabIndex = 2;
            this.txtAddress.Text = "address(es) of contact";
            this.txtAddress.TextChanged += new System.EventHandler(this.txtAddress_TextChanged);
            // 
            // txtEmail
            // 
            this.txtEmail.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtEmail.Location = new System.Drawing.Point(88, 400);
            this.txtEmail.Name = "txtEmail";
            this.txtEmail.Size = new System.Drawing.Size(312, 21);
            this.txtEmail.TabIndex = 3;
            this.txtEmail.Text = "email address(es) of contact";
            this.txtEmail.TextChanged += new System.EventHandler(this.txtEmail_TextChanged);
            // 
            // txtPhone
            // 
            this.txtPhone.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtPhone.Location = new System.Drawing.Point(88, 424);
            this.txtPhone.Name = "txtPhone";
            this.txtPhone.Size = new System.Drawing.Size(312, 21);
            this.txtPhone.TabIndex = 4;
            this.txtPhone.Text = "phone number(s) of contact";
            this.txtPhone.TextChanged += new System.EventHandler(this.txtPhone_TextChanged);
            // 
            // lblName
            // 
            this.lblName.BackColor = System.Drawing.SystemColors.ActiveBorder;
            this.lblName.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblName.Location = new System.Drawing.Point(8, 352);
            this.lblName.Name = "lblName";
            this.lblName.Size = new System.Drawing.Size(72, 16);
            this.lblName.TabIndex = 8;
            this.lblName.Text = "Name";
            this.lblName.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // lblAddress
            // 
            this.lblAddress.BackColor = System.Drawing.Color.Transparent;
            this.lblAddress.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblAddress.Location = new System.Drawing.Point(8, 376);
            this.lblAddress.Name = "lblAddress";
            this.lblAddress.Size = new System.Drawing.Size(72, 16);
            this.lblAddress.TabIndex = 9;
            this.lblAddress.Text = "Address";
            this.lblAddress.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // lblEmail
            // 
            this.lblEmail.BackColor = System.Drawing.Color.Transparent;
            this.lblEmail.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblEmail.ForeColor = System.Drawing.Color.Black;
            this.lblEmail.Location = new System.Drawing.Point(8, 400);
            this.lblEmail.Name = "lblEmail";
            this.lblEmail.Size = new System.Drawing.Size(72, 16);
            this.lblEmail.TabIndex = 10;
            this.lblEmail.Text = "Email";
            this.lblEmail.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            this.lblEmail.Click += new System.EventHandler(this.lblEmail_Click);
            // 
            // lblPhone
            // 
            this.lblPhone.BackColor = System.Drawing.Color.Transparent;
            this.lblPhone.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblPhone.Location = new System.Drawing.Point(8, 424);
            this.lblPhone.Name = "lblPhone";
            this.lblPhone.Size = new System.Drawing.Size(72, 16);
            this.lblPhone.TabIndex = 11;
            this.lblPhone.Text = "Phone";
            this.lblPhone.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // btnBrowsePhoto
            // 
            this.btnBrowsePhoto.BackColor = System.Drawing.SystemColors.ActiveBorder;
            this.btnBrowsePhoto.Location = new System.Drawing.Point(212, 536);
            this.btnBrowsePhoto.Name = "btnBrowsePhoto";
            this.btnBrowsePhoto.Size = new System.Drawing.Size(104, 23);
            this.btnBrowsePhoto.TabIndex = 14;
            this.btnBrowsePhoto.Text = "&Browse for Photo";
            this.btnBrowsePhoto.UseVisualStyleBackColor = false;
            this.btnBrowsePhoto.Click += new System.EventHandler(this.btnBrowsePhoto_Click);
            // 
            // txtNotes
            // 
            this.txtNotes.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtNotes.Location = new System.Drawing.Point(440, 80);
            this.txtNotes.Multiline = true;
            this.txtNotes.Name = "txtNotes";
            this.txtNotes.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtNotes.Size = new System.Drawing.Size(328, 368);
            this.txtNotes.TabIndex = 9;
            this.txtNotes.Text = "Notes";
            this.txtNotes.TextChanged += new System.EventHandler(this.txtNotes_TextChanged);
            // 
            // btnOpen
            // 
            this.btnOpen.Location = new System.Drawing.Point(110, 536);
            this.btnOpen.Name = "btnOpen";
            this.btnOpen.Size = new System.Drawing.Size(96, 24);
            this.btnOpen.TabIndex = 13;
            this.btnOpen.Text = "&Open Contact";
            this.btnOpen.Click += new System.EventHandler(this.btnOpen_Click);
            // 
            // btnNew
            // 
            this.btnNew.Location = new System.Drawing.Point(16, 536);
            this.btnNew.Name = "btnNew";
            this.btnNew.Size = new System.Drawing.Size(88, 24);
            this.btnNew.TabIndex = 12;
            this.btnNew.Text = "&New Contact";
            this.btnNew.Click += new System.EventHandler(this.btnNew_Click);
            // 
            // pnlPassword
            // 
            this.pnlPassword.Controls.Add(this.lblMinLength);
            this.pnlPassword.Controls.Add(this.txtConfirmPassword);
            this.pnlPassword.Controls.Add(this.lblConfirmPassword);
            this.pnlPassword.Controls.Add(this.lblPassword);
            this.pnlPassword.Controls.Add(this.txtPassword);
            this.pnlPassword.Location = new System.Drawing.Point(504, 454);
            this.pnlPassword.Name = "pnlPassword";
            this.pnlPassword.Size = new System.Drawing.Size(264, 132);
            this.pnlPassword.TabIndex = 12;
            // 
            // lblMinLength
            // 
            this.lblMinLength.AutoSize = true;
            this.lblMinLength.Location = new System.Drawing.Point(13, 66);
            this.lblMinLength.Name = "lblMinLength";
            this.lblMinLength.Size = new System.Drawing.Size(214, 13);
            this.lblMinLength.TabIndex = 14;
            this.lblMinLength.Text = "Minimum password length is five characters.";
            // 
            // txtConfirmPassword
            // 
            this.txtConfirmPassword.Font = new System.Drawing.Font("Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtConfirmPassword.Location = new System.Drawing.Point(144, 37);
            this.txtConfirmPassword.MaxLength = 10;
            this.txtConfirmPassword.Name = "txtConfirmPassword";
            this.txtConfirmPassword.PasswordChar = '*';
            this.txtConfirmPassword.Size = new System.Drawing.Size(112, 21);
            this.txtConfirmPassword.TabIndex = 11;
            this.txtConfirmPassword.TextChanged += new System.EventHandler(this.txtConfirmPassword_TextChanged);
            // 
            // lblConfirmPassword
            // 
            this.lblConfirmPassword.AutoSize = true;
            this.lblConfirmPassword.Location = new System.Drawing.Point(13, 32);
            this.lblConfirmPassword.Name = "lblConfirmPassword";
            this.lblConfirmPassword.Size = new System.Drawing.Size(94, 13);
            this.lblConfirmPassword.TabIndex = 12;
            this.lblConfirmPassword.Text = "Confirm Password:";
            this.lblConfirmPassword.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // lblPassword
            // 
            this.lblPassword.Location = new System.Drawing.Point(8, 8);
            this.lblPassword.Name = "lblPassword";
            this.lblPassword.Size = new System.Drawing.Size(128, 24);
            this.lblPassword.TabIndex = 2;
            this.lblPassword.Text = "Contact File Password:";
            this.lblPassword.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // txtPassword
            // 
            this.txtPassword.Font = new System.Drawing.Font("Microsoft Sans Serif", 9F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtPassword.Location = new System.Drawing.Point(144, 8);
            this.txtPassword.MaxLength = 10;
            this.txtPassword.Name = "txtPassword";
            this.txtPassword.PasswordChar = '*';
            this.txtPassword.Size = new System.Drawing.Size(112, 21);
            this.txtPassword.TabIndex = 10;
            this.txtPassword.TextChanged += new System.EventHandler(this.txtPassword_TextChanged);
            // 
            // btnDelete
            // 
            this.btnDelete.Location = new System.Drawing.Point(392, 536);
            this.btnDelete.Name = "btnDelete";
            this.btnDelete.Size = new System.Drawing.Size(96, 24);
            this.btnDelete.TabIndex = 16;
            this.btnDelete.Text = "&Delete Contact";
            this.btnDelete.Click += new System.EventHandler(this.btnDelete_Click);
            // 
            // lblYahooID
            // 
            this.lblYahooID.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblYahooID.Location = new System.Drawing.Point(16, 448);
            this.lblYahooID.Name = "lblYahooID";
            this.lblYahooID.Size = new System.Drawing.Size(64, 16);
            this.lblYahooID.TabIndex = 13;
            this.lblYahooID.Text = "Yahoo ID";
            this.lblYahooID.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // txtYahooID
            // 
            this.txtYahooID.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtYahooID.Location = new System.Drawing.Point(88, 448);
            this.txtYahooID.Name = "txtYahooID";
            this.txtYahooID.Size = new System.Drawing.Size(128, 20);
            this.txtYahooID.TabIndex = 5;
            this.txtYahooID.Text = "Yahoo ID";
            this.txtYahooID.TextChanged += new System.EventHandler(this.txtYahooID_TextChanged);
            // 
            // lblBirthday
            // 
            this.lblBirthday.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblBirthday.Location = new System.Drawing.Point(16, 472);
            this.lblBirthday.Name = "lblBirthday";
            this.lblBirthday.Size = new System.Drawing.Size(64, 16);
            this.lblBirthday.TabIndex = 15;
            this.lblBirthday.Text = "Birthday";
            this.lblBirthday.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // txtBirthday
            // 
            this.txtBirthday.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtBirthday.Location = new System.Drawing.Point(88, 472);
            this.txtBirthday.Name = "txtBirthday";
            this.txtBirthday.Size = new System.Drawing.Size(128, 20);
            this.txtBirthday.TabIndex = 6;
            this.txtBirthday.Text = "Date of Birth";
            this.txtBirthday.TextChanged += new System.EventHandler(this.txtBirthday_TextChanged);
            // 
            // lblEducation
            // 
            this.lblEducation.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblEducation.Location = new System.Drawing.Point(16, 496);
            this.lblEducation.Name = "lblEducation";
            this.lblEducation.Size = new System.Drawing.Size(64, 16);
            this.lblEducation.TabIndex = 17;
            this.lblEducation.Text = "Education";
            this.lblEducation.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // txtEducation
            // 
            this.txtEducation.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtEducation.Location = new System.Drawing.Point(88, 496);
            this.txtEducation.Name = "txtEducation";
            this.txtEducation.Size = new System.Drawing.Size(128, 20);
            this.txtEducation.TabIndex = 7;
            this.txtEducation.Text = "Education Level";
            this.txtEducation.TextChanged += new System.EventHandler(this.txtEducation_TextChanged);
            // 
            // lblOccupation
            // 
            this.lblOccupation.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblOccupation.Location = new System.Drawing.Point(440, 24);
            this.lblOccupation.Name = "lblOccupation";
            this.lblOccupation.Size = new System.Drawing.Size(72, 16);
            this.lblOccupation.TabIndex = 19;
            this.lblOccupation.Text = "Occupation";
            this.lblOccupation.TextAlign = System.Drawing.ContentAlignment.BottomRight;
            // 
            // txtOccupation
            // 
            this.txtOccupation.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtOccupation.Location = new System.Drawing.Point(520, 24);
            this.txtOccupation.Multiline = true;
            this.txtOccupation.Name = "txtOccupation";
            this.txtOccupation.Size = new System.Drawing.Size(248, 40);
            this.txtOccupation.TabIndex = 8;
            this.txtOccupation.Text = "Occupation";
            this.txtOccupation.TextChanged += new System.EventHandler(this.txtOccupation_TextChanged);
            // 
            // linkLabel1
            // 
            this.linkLabel1.AutoSize = true;
            this.linkLabel1.LinkArea = new System.Windows.Forms.LinkArea(10, 100);
            this.linkLabel1.Location = new System.Drawing.Point(16, 573);
            this.linkLabel1.Name = "linkLabel1";
            this.linkLabel1.Size = new System.Drawing.Size(494, 17);
            this.linkLabel1.TabIndex = 20;
            this.linkLabel1.TabStop = true;
            this.linkLabel1.Text = "for help: http://www.geocities.com/deornoth.stelgaard/myInstalls/install_img/lb10" +
                "00/more_info.htm";
            this.linkLabel1.UseCompatibleTextRendering = true;
            this.linkLabel1.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.linkLabel1_LinkClicked);
            // 
            // Form1
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.BackColor = System.Drawing.SystemColors.ActiveBorder;
            this.ClientSize = new System.Drawing.Size(802, 599);
            this.Controls.Add(this.linkLabel1);
            this.Controls.Add(this.txtOccupation);
            this.Controls.Add(this.lblOccupation);
            this.Controls.Add(this.txtEducation);
            this.Controls.Add(this.lblEducation);
            this.Controls.Add(this.txtBirthday);
            this.Controls.Add(this.lblBirthday);
            this.Controls.Add(this.txtYahooID);
            this.Controls.Add(this.lblYahooID);
            this.Controls.Add(this.btnDelete);
            this.Controls.Add(this.pnlPassword);
            this.Controls.Add(this.btnNew);
            this.Controls.Add(this.btnOpen);
            this.Controls.Add(this.txtNotes);
            this.Controls.Add(this.btnBrowsePhoto);
            this.Controls.Add(this.lblPhone);
            this.Controls.Add(this.lblEmail);
            this.Controls.Add(this.lblAddress);
            this.Controls.Add(this.lblName);
            this.Controls.Add(this.txtPhone);
            this.Controls.Add(this.txtEmail);
            this.Controls.Add(this.txtAddress);
            this.Controls.Add(this.txtName);
            this.Controls.Add(this.btnSaveInfo);
            this.Controls.Add(this.picImage);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedSingle;
            this.MaximizeBox = false;
            this.Name = "Form1";
            this.StartPosition = System.Windows.Forms.FormStartPosition.Manual;
            this.Text = "Contacts Book";
            this.Load += new System.EventHandler(this.Form1_Load);
            ((System.ComponentModel.ISupportInitialize)(this.picImage)).EndInit();
            this.pnlPassword.ResumeLayout(false);
            this.pnlPassword.PerformLayout();
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion

		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}


		private void btnSaveInfo_Click(object sender, System.EventArgs e)
		{
			//for button btnSaveInfo
            bool overwrite = true;
            
            current_contact = txtName.Text;
            current_contact = contacts_directory + current_contact + ".crf";
            fileDialog.FileName = current_contact;

            //MessageBox.Show(current_contact);

			//this button is clicked to save all fields of a record, so
			//this button should only be enabled if all textboxes have
			//valid values, and the picturebox shows a picture of the contact.
			
            //if this file is already on disk, ask before overwriting it
            if (File.Exists(current_contact))
            {

                string s = "This contact already exists on disk.  Overwrite?";
                DialogResult result = MessageBox.Show(s, "Overwrite Existing File?", MessageBoxButtons.YesNo);
                if (result == DialogResult.Yes)
                {
                    overwrite = true;
                }
                else
                {
                    overwrite = false;
                }
            }
            else
            {
                //MessageBox.Show("Doesn't exist: " + current_contact);
            }

            if (overwrite)
            {

                // Create the contact
                Contact con = new Contact();

                // Fill it full of information
                con.Name = txtName.Text;
                con.Notes = txtNotes.Text;
                con.Address = txtAddress.Text;
                con.Email = txtEmail.Text;
                con.Phone = txtPhone.Text;
                con.Password = txtPassword.Text;
                con.Yahoo_id = txtYahooID.Text;
                con.Birthday = txtBirthday.Text;
                con.Education = txtEducation.Text;
                con.Occupation = txtOccupation.Text;
                con.Mybmp = (Bitmap)picImage.Image;

                // Save it
                try
                {
                    // Prepare to serialize it

                    //MessageBox.Show(app_directory);


                    Stream outStream = File.Create(current_contact);
                    BinaryFormatter serializer = new BinaryFormatter();

                    // Serialize it
                    serializer.Serialize(outStream, con);

                    // Close the stream; don't forget!
                    outStream.Close();

                    contact_loaded = true;
                    btnDelete.Enabled = true;
                    DisplayNumContactsInFormCaption();

                    btnNew.Focus();

                    //uncommenting the following line of code will cause this file
                    //to NOT be deleteable from within the application; it can still be
                    //deleted manually.

                    //File.SetAttributes(current_contact, FileAttributes.System);

                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message);
                    if (ex.Message == "The given path's format is not supported.")
                    {
                        txtName.Focus();
                    }
                }

                txtPassword.Text = "";
                btnSaveInfo.Enabled = false;
            }
		}

		private void btnBrowsePhoto_Click(object sender, System.EventArgs e)
		{
			fileDialog.Title = "Browse for photo";
			fileDialog.Filter = "Jpeg Image File (*.jpg)|*.jpg";
			bool myfile_exists = fileDialog.CheckFileExists;
		
			DialogResult dr = fileDialog.ShowDialog();
			switch (dr)
			{
				case DialogResult.Cancel:
					break;//user doesn't wanna open a file after all...
				case DialogResult.OK:
					if (myfile_exists)
						myfile_exists = CheckForJpegExtension(fileDialog.FileName);
						if (myfile_exists)
						{
							picImage.Image = Image.FromFile(fileDialog.FileName);

                            if (txtName.Text.Length > 3)
                            {
                                EnsureNameOtherThanDefault();
                               
                            }
                            else
                            {
                                btnSaveInfo.Enabled = false;
                            }
						}
						else
							MessageBox.Show("That's not a JPEG file!","Error!",MessageBoxButtons.OK);
					break;
				default:
					break;
			}//end switch structure, c#'s equiv for VB's Select Case
		}



        private void CheckForValidEmail()
        {
            //checks to see if a valid email is in the txtEmail textbox
            //if so, changes the lblEmail label's font color to blue
            //if not, changes it to black

            if (txtEmail.Text.Length > 4)
            {
                //lblEmail.ForeColor = Color.Blue;
                int length = txtEmail.Text.Length;
                int period = txtEmail.Text.IndexOf(".");
                //string s = "length = " + length.ToString() + ", period index = " + period.ToString();
                //s += ", txtEmail.Text = " + txtEmail.Text;
                //MessageBox.Show(s);
                if (period != -1)
                {
                    if (length - period == 4)
                    {
                        lblEmail.ForeColor = Color.Blue;
                    }
                    else
                    {
                        lblEmail.ForeColor = Color.Black;
                    }
                }
                else
                {
                    lblEmail.ForeColor = Color.Black;
                }
            }
            else
            {
                lblEmail.ForeColor = Color.Black;
            }
        }

        private void IntegrateWithShell()
        {
      

        

            // //Register custom extension with the shell

            ////root...

            //using (RegistryKey key =
            //        Registry.ClassesRoot.CreateSubKey(".crf"))
            //{
            //    // Map custom  extension to a ProgID
            //    key.SetValue(null, "crffile");
            //    key.Close();
            //}

            //// Register open command with the shell
            //string cmdkey = @"crffile\shell\open\command";
            //using (RegistryKey key =
            //         Registry.ClassesRoot.CreateSubKey(cmdkey))
            //{
            //    // Map ProgID to an Open action for the shell
            //    key.SetValue(null, Application.ExecutablePath + " \"%1\"");
            //    key.Close();
            //}

            //// Register custom extension with the shell
            //using (RegistryKey key2 =
            //        Registry.ClassesRoot.CreateSubKey("crf_auto_file"))
            //{
            //    // Map custom  extension to a ProgID
            //    key2.SetValue(null, "Contact Resource File");
            //    key2.Close();
            //}

            //// Register open command with the shell
            //string cmdkey2 = @"crf_auto_file\shell\open\command";
            //using (RegistryKey key2 =
            //         Registry.ClassesRoot.CreateSubKey(cmdkey2))
            //{
            //    // Map ProgID to an Open action for the shell
            //    key2.SetValue(null, Application.ExecutablePath + " \"%1\"");
            //    key2.Close();
            //}

            ////local machine


            ////Register custom extension with the shell
            //using (RegistryKey key3 =
            //        Registry.LocalMachine.CreateSubKey("Software\\Classes\\.crf"))
            //{
            //    // Map custom  extension to a ProgID
            //    key3.SetValue(null, "crffile");
            //    key3.Close();
            //}

            //// Register open command with the shell
            //string cmdkey3 = @"crffile\shell\open\command";
            //using (RegistryKey key3 =
            //         Registry.LocalMachine.CreateSubKey(cmdkey3))
            //{
            //    // Map ProgID to an Open action for the shell
            //    key3.SetValue(null, Application.ExecutablePath + " \"%1\"");
            //    key3.Close();
            //}

            //// Register custom extension with the shell
            //using (RegistryKey key4 =
            //        Registry.LocalMachine.CreateSubKey("Software\\Classes\\crf_auto_file"))
            //{
            //    // Map custom  extension to a ProgID
            //    key4.SetValue(null, "Contact Resource File");
            //    key4.Close();
            //}

            //// Register open command with the shell
            //string cmdkey4 = @"crf_auto_file\shell\open\command";
            //using (RegistryKey key4 =
            //         Registry.LocalMachine.CreateSubKey(cmdkey4))
            //{
            //    // Map ProgID to an Open action for the shell
            //    key4.SetValue(null, Application.ExecutablePath + " \"%1\"");
            //    key4.Close();
            //}

            ////current user

            ////Register custom extension with the shell
            //using (RegistryKey key5 =
            //        Registry.LocalMachine.CreateSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\FileExts\\.crf\\OpenWithProgids"))
            //{
            //    // Map custom  extension to a ProgID
            //    key5.SetValue(null, "crffile");
            //    key5.Close();
            //}

            //// Register open command with the shell
            //string cmdkey5 = @"crffile\shell\open\command";
            //using (RegistryKey key5 =
            //         Registry.LocalMachine.CreateSubKey(cmdkey5))
            //{
            //    // Map ProgID to an Open action for the shell
            //    key5.SetValue(null, Application.ExecutablePath + " \"%1\"");
            //    key5.Close();
            //}

            //// Register custom extension with the shell
            //using (RegistryKey key6 =
            //        Registry.LocalMachine.CreateSubKey("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\FileExts\\.crf\\OpenWithProgids"))
            //{
            //    // Map custom  extension to a ProgID
            //    key6.SetValue(null, "Contact Resource File");
            //    key6.Close();
            //}

            //// Register open command with the shell
            //string cmdkey6 = @"crf_auto_file\shell\open\command";
            //using (RegistryKey key6 =
            //         Registry.LocalMachine.CreateSubKey(cmdkey6))
            //{
            //    // Map ProgID to an Open action for the shell
            //    key6.SetValue(null, Application.ExecutablePath + " \"%1\"");
            //    key6.Close();
            //}


            ////Software\Microsoft\Windows\CurrentVersion\Explorer\FileExts\.crf\OpenWithProgids
        }

		private void DoForm1ConstructorStuff()
		{

            //MessageBox.Show(Application.ExecutablePath);
            this.Icon = lovebook.Properties.Resources.person;
            IntegrateWithShell();

            //concat a string showing path where Contacts subdirectory SHOULD be...
			int myindex = Application.ExecutablePath.IndexOf("bin");
            app_directory = Application.ExecutablePath.Substring(0, myindex + 4);
            contacts_directory = app_directory + "Contacts\\";
            //MessageBox.Show(contacts_directory, "Contacts Directory");
           
            //if Contacts subdirectory ISN'T there, create it
            bool exists = Directory.Exists(contacts_directory);
            if (!exists)
            {
                Directory.CreateDirectory(contacts_directory);
            }
			

			//size the form
			this.Height = 620;
			this.Width = 800;
			
			DisplayNumContactsInFormCaption();

			btnBrowsePhoto.Enabled = false;
			btnSaveInfo.Enabled = false;
			btnDelete.Enabled = false;
            txtConfirmPassword.Visible = false;
            lblConfirmPassword.Visible = false;
            lblMinLength.Visible = false;

            lblMinLength.Text = "Minimum password length is five characters.\n";
            lblMinLength.Text += "Maximum password length is ten characters.";

			//load placeholder image into picturebox

            picImage.Image = lovebook.Properties.Resources.myself;

            //assign text property to the labels
			lblName.Text = "Name: ";
			lblPhone.Text = "Phone: ";
			lblAddress.Text = "Address: ";
			lblEmail.Text = "Email: ";
			lblYahooID.Text = "Yahoo ID: ";
			lblBirthday.Text = "Birthday: ";
			lblEducation.Text = "Education: ";
			lblOccupation.Text = "Occupation: ";

			//fill textboxes with placeholder values
			txtName.Text = "Yours Truly";
			txtNotes.Text = "The awesome programmer of this application!";
			txtPhone.Text = "(555)-555-5555";
			txtAddress.Text = "123 Anyplace Drive, Someplace, Some State, 12345";
			txtEmail.Text = "mrcool@yourstruly.com";
			txtYahooID.Text = "kyrathaba";
			txtBirthday.Text = "07/26/71";
			txtEducation.Text = "Masters degree";
			txtOccupation.Text = "Counselor";

            CheckForValidEmail();

            string[] myargs = System.Environment.GetCommandLineArgs();

            foreach (string args in myargs)
            {
                int ind = args.IndexOf(".crf");
                if (ind != -1)
                {
                    PassValidFileToContactOpener(args);
                    break;
                }//end if
            }//end foreach

		}//end method DoForm1ConstructorStuff()



		private bool CheckForJpegExtension(string filepath)
		{
			//take the passed filepath and see if the filename has
			//a .jpg extension; return true or false
		
			string fragment = filepath.Substring(filepath.Length-3,3);
			if (fragment.ToLower() == "jpg")
				return true;
			else
				return false;

		}



		private void picImage_Click(object sender, System.EventArgs e)
		{
		
		}

		private void btnOpen_Click(object sender, System.EventArgs e)
		{
			//MessageBox.Show(contacts_directory);
			
			fileDialog.Title = "Open a Contact";
			fileDialog.Filter = "Contact Resource File (*.crf)|*.crf";
			
			fileDialog.InitialDirectory = contacts_directory;

			//MessageBox.Show(Directory.GetCurrentDirectory() + " : " + contacts_directory);

			bool myfile_exists = fileDialog.CheckFileExists;
		
			DialogResult dr = fileDialog.ShowDialog();
			switch (dr)
			{
				case DialogResult.Cancel:
					break;//user doesn't wanna open a file after all...
				
				case DialogResult.OK:
					
					if (myfile_exists)
					{
						//load the contact info into a variable of type contact
						//...process everything and show to user...

                        PassValidFileToContactOpener(fileDialog.FileName);

					}//end if
					
					break;
				
				default:
					
					MessageBox.Show("There was an error during file-opening", "Error Opening Contact File",
		           MessageBoxButtons.OK, MessageBoxIcon.Error);

					break;
			
			}//end switch structure, c#'s equiv for VB's Select Case
		
		}//end btnOpen_Click()


        private void PassValidFileToContactOpener(string filepath)
        {
            //load the serialized file
            try
            {
                // Open stream
                Stream inStream = File.OpenRead(filepath);
                BinaryFormatter deserializer = new BinaryFormatter();
                // Put serialized info in class instance
                Contact con = (Contact)(deserializer.Deserialize(inStream));
                inStream.Close();
                //MessageBox.Show("Deserialization Successful!");

                //check to see if a password is required of user

                string s = "Enter correct password before attempting to open Contact. ";

                switch (con.Password)
                {
                    case "":
                        //assign info held in the variable of type Contact back to
                        //appropriate controls on the form

                        LoadSelectedContact(con);
                        CheckForValidEmail();
                        break;

                    default:
                        if (txtPassword.Text.ToLower() != con.Password.ToLower())
                        {
                            if (txtPassword.Text.Length > 0)
                            {
                                s = s + "The password currently in the password textbox ";
                                s = s + "is incorrect!";
                            }//end if
                            MessageBox.Show(s, "Password Required");
                            txtPassword.Text = "";
                            txtPassword.Focus();

                        }
                        else
                        {
                            //MessageBox.Show("txtPassword=" + txtPassword.Text + ", " + "con.Password=" + con.Password);
                            LoadSelectedContact(con);
                            CheckForValidEmail();

                        }//end fi
                        break;

                }//end switch

            }//end try
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }//end catch

        }
        

		private void LoadSelectedContact(Contact con)
		{
			txtName.Text = con.Name;
			txtNotes.Text = con.Notes;
			txtAddress.Text = con.Address;
			txtEmail.Text = con.Email;
			txtPhone.Text = con.Phone;
			txtYahooID.Text = con.Yahoo_id;
			txtBirthday.Text = con.Birthday;
			txtEducation.Text = con.Education;
			txtOccupation.Text = con.Occupation;
			picImage.Image = (Bitmap)con.Mybmp;
			contact_loaded = true;
			btnDelete.Enabled = true;
			btnBrowsePhoto.Enabled = true;
			DisplayNumContactsInFormCaption();
            txtPassword.Text = "";
		}


		private void DisplayNumContactsInFormCaption()
		{
			//update form caption with total number of contact resource
			//files found in the Contacts directory (these are *.crf files).
			//This will be called in the form's constructor, and anytime a
			//contact file is saved or deleted.
							
			string[] s = Directory.GetFiles(contacts_directory, "*.crf");
			string cap = form_caption;
			cap = cap + " - " + s.Length.ToString() + " contact ";
			if (s.Length == 1)
			cap = cap + "file ";
			else
			cap = cap + "files ";
			cap = cap + "found in \"Contacts\" directory ";
			if (contact_loaded)
				cap = cap + "[A saved contact is currently loaded]";
			else
				cap = cap + "[No contact currently loaded]";
			this.Text = cap;
		}

		
		private void btnNew_Click(object sender, System.EventArgs e)
		{
            SetCodeForNewCommandButtonClicked();

        }

        private void SetCodeForNewCommandButtonClicked()
        {
            btnBrowsePhoto.Enabled = true;
            btnDelete.Enabled = false;
            btnSaveInfo.Enabled = false;
            txtName.Text = "DEFAULT NAME VALUE: replace me by typing here";
            txtAddress.Text = "";
            txtPhone.Text = "";
            txtEmail.Text = "";
            txtNotes.Text = "";
            txtYahooID.Text = "";
            txtBirthday.Text = "";
            txtEducation.Text = "";
            txtOccupation.Text = "";
            picImage.Image = null;
            txtName.Focus();
            contact_loaded = false;
            DisplayNumContactsInFormCaption();
            txtName.Focus();
        }

        private void EnsureNameOtherThanDefault()
        {
            if (txtName.Text == "DEFAULT NAME VALUE: replace me by typing here")
            {
                btnSaveInfo.Enabled = false;
            }
            else
            {
                btnSaveInfo.Enabled = true;
            }
        }


		private void txtName_TextChanged(object sender, System.EventArgs e)
		{
            if (txtName.Text.Length > 3)
                EnsureNameOtherThanDefault();
		}


		private void btnDelete_Click(object sender, System.EventArgs e)
		{
			//delete's the currently loaded contact from the Contacts directory

            //blank out everything else so it looks on the GUI like we've deleted the contact
            if (fileDialog.FileName != "")
            {
                if(File.Exists(fileDialog.FileName))
                {
                    File.Delete(fileDialog.FileName);
                    contact_loaded = false; //must be set before call to DisplayNum...
                    DisplayNumContactsInFormCaption();
                    btnDelete.Enabled = false;
                    fileDialog.FileName = "";
                    btnSaveInfo.Enabled = false;
                    btnBrowsePhoto.Enabled = false;
                   

                    foreach (Control control in this.Controls)
                    {

                        if (control.GetType() == typeof(TextBox))
                        {
                            if (control.Name != "txtName")
                            {
                                control.Text = "";
                            }
                            else
                            {
                                txtName.Text = "you need to click the New button...";
                            }//end if
                        }//end if(control.GetType()...
                          
                    }//end foreach

                    picImage.Image = null;

                    btnNew.Enabled = true;

                    SetCodeForNewCommandButtonClicked();
                
                }//end if(File.Exists...

            }
            else
            {
                MessageBox.Show("fileDialog.FileName is empty so btnDelete should not have been enabled!");
            }
		}

        private void txtPassword_TextChanged(object sender, EventArgs e)
        {
            checkPasswordCheckboxes();  
        }



        private void txtConfirmPassword_TextChanged(object sender, EventArgs e)
        {
            checkPasswordCheckboxes();
        }


        private void checkPasswordCheckboxes()
        {
            if (txtPassword.Text.Length == 0)//begin outer if
            {
                lblConfirmPassword.Visible = false;
                txtConfirmPassword.Visible = false;
                lblMinLength.Visible = false;
                if (txtName.Text.Length > 3)
                {
                    EnsureNameOtherThanDefault();
                   
                }
                else
                {
                    btnSaveInfo.Enabled = false;
                }
            }
            else
            {
                //user must match this text by typing into txtConfirmPassword textbox
                if (txtConfirmPassword.Text == txtPassword.Text)//begin if2
                {

                    if (txtPassword.Text.Length > 4)//begin if3
                    {
                        if (txtName.Text.Length > 3)
                        {
                            EnsureNameOtherThanDefault();
                           
                        }
                        else
                        {
                            btnSaveInfo.Enabled = false;
                        }
                        lblConfirmPassword.Visible = false;
                        txtConfirmPassword.Visible = false;
                        lblMinLength.Visible = false;
                        btnOpen.Focus();
                    }
                    else
                    {
                        btnSaveInfo.Enabled = false;
                        lblConfirmPassword.Visible = true;
                        txtConfirmPassword.Visible = true;
                        lblMinLength.Text = "Minimum password length is five characters.\n";
                        lblMinLength.Text += "Maximum password length is ten characters.";
                        lblMinLength.Visible = true;
                    }
                }
                else
                {
                    btnSaveInfo.Enabled = false;
                    lblConfirmPassword.Visible = true;
                    txtConfirmPassword.Visible = true;
                    lblMinLength.Text = "Confirmation password doesn't match original.\n";
                    if (txtPassword.Text.Length < 5)
                    {
                        lblMinLength.Text += "Minimum password length is five characters.\n";
                        lblMinLength.Text += "Maximum password length is ten characters.";
                    }
                    lblMinLength.Visible = true;

                }//end if2


            }//end outer if
        }

        private void txtAddress_TextChanged(object sender, EventArgs e)
        {
            if (txtName.Text.Length > 3)
            {
                EnsureNameOtherThanDefault();
               
            }
        }

        private void txtEmail_TextChanged(object sender, EventArgs e)
        {
            if (txtName.Text.Length > 3)
            {
                EnsureNameOtherThanDefault();
                
            }
            CheckForValidEmail();
        }

        private void txtPhone_TextChanged(object sender, EventArgs e)
        {
            if (txtName.Text.Length > 3)
            {
                EnsureNameOtherThanDefault();
               
            }
        }

        private void txtYahooID_TextChanged(object sender, EventArgs e)
        {
            if (txtName.Text.Length > 3)
            {
                EnsureNameOtherThanDefault();
                
            }
        }

        private void txtBirthday_TextChanged(object sender, EventArgs e)
        {
            if (txtName.Text.Length > 3)
            {
                EnsureNameOtherThanDefault();
                
            }
        }

        private void txtEducation_TextChanged(object sender, EventArgs e)
        {
            if (txtName.Text.Length > 3)
            {
                EnsureNameOtherThanDefault();
                
            }
        }

        private void txtOccupation_TextChanged(object sender, EventArgs e)
        {
            if (txtName.Text.Length > 3)
            {
                EnsureNameOtherThanDefault();
                
            }
        }

        private void txtNotes_TextChanged(object sender, EventArgs e)
        {
            if (txtName.Text.Length > 3)
            {
                EnsureNameOtherThanDefault();
                
            }
        }

        private void lblEmail_Click(object sender, EventArgs e)
        {
            if (lblEmail.ForeColor == Color.Blue)
            {
                System.Diagnostics.Process.Start("mailto:" + txtEmail.Text);
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {

            

        }

        private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            string s = "http://www.geocities.com/deornoth.stelgaard/myInstalls/install_img/lb1000/more_info.htm";

            System.Diagnostics.Process.Start(s);

        }

		
	}//end class Form1


	[Serializable]
	public class Contact 
	{
		private string name = "";
		private string address = "";
		private string email = "";
		private string phone = "";
		private string notes = "";
		private string password = "";
		private string yahoo_id = "";
		private string birthday = "";
		private string education = "";
		private string occupation = "";
		private Bitmap mybmp = null;


		//let's define the properties of our Contact class...

		public string Occupation
		{
			set
			{
				occupation = value;
			}
			get
			{
				return occupation;
			}
		}
		
		public string Education
		{
			set
			{
				education = value;
			}
			get
			{
				return education;
			}
		}


		public string Birthday
		{
			set
			{
				birthday = value;
			}
			get
			{
				return birthday;
			}
		}


		public string Yahoo_id
		{
			set
			{
				yahoo_id = value;
			}
			get
			{
				return yahoo_id;
			}
		}


		public string Password
		{
			set
			{
				password = value;
			}//end set
			get
			{
				return password;
			}
		}//end password property


		public string Notes
		{
			set
			{
				notes = value;
			}//end set
			get
			{
				return notes;
			}//end get
		}//end notes property


		public string Name 
		{
			set 
			{
				name = value;
			}//end set
			get 
			{
				return name;
			}//end get
		}//end name property


		public string Address
		{
			set
			{
				address = value;
			}//end set
			get
			{
				return address;
			}//end get
		}//end address property

	
		public string Phone
		{
			set
			{
				phone = value;
			}//end set
			get
			{
				return phone;
			}//end set
		}//end phone property


		public string Email
		{
			set
			{
				email = value;
			}
			get
			{
				return email;
			}
		}//end email property


		public Bitmap Mybmp
		{
			set
			{
				mybmp = value;
			}
			get
			{
				//return (Bitmap) mybmp.Clone();
				return mybmp;
			}
		}//end bitmap property

	}//end class Contact



}//end namespace lovebook
